DroplessInterner

Struct DroplessInterner 

pub struct DroplessInterner<'a, T: Eq + Hash> {
    arena: DroplessArena<'a>,
    keys: RwLock<HashSet<&'a T>>,
}
A DroplessInterner hands out Interned references for arbitrary types.

See the module-level documentation for more information.

Fields

arena: DroplessArena<'a>keys: RwLock<HashSet<&'a T>>

Implementations

Source

impl<'a, T: Eq + Hash> DroplessInterner<'a, T>

pub fn new(arena: DroplessArena<'a>) -> Self

Creates a new DroplessInterner backed by the provided DroplessArena

Panics

Panics if T needs drop

pub fn get_or_insert(&'a self, value: T) -> Interned<'a, T>

Converts the given value into an Interned value.

Blocks

This function blocks when the interner is held by another thread.

pub fn get(&self, value: &T) -> Option<Interned<'a, T>>

Returns the Interned copy of the given value, if one already exists

Blocks

This function blocks when the interner is being written to by another thread.